@@ -17,10 +17,13 @@ OC.L10N.register(
     "Download" : "Hämta",
     "Close" : "Stäng",
     "Web address" : "Webbadress",
+    "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
     "No folder" : "Ingen mapp",
     "Folder name" : "Mappnamn",
     "Username" : "Användarnamn",
     "Password" : "Lösenord",
+    "Internal server error!" : "Internt serverfel!",
+    "Unknown error!" : "Okänt fel!",
     "Feed exists already!" : "Flödet finns redan!",
     "New folder" : "Ny mapp",
     "Folder exists already!" : "Katalogen finns redan",
@@ -45,11 +48,12 @@ OC.L10N.register(
     "How many redirects the feed fetcher should follow." : "Hur många omdirigeringar flödet skall tillåtas följa.",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
     "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
+    "Use next update time for feed updates" : "Använd nästa uppdateringstid för flödesuppdateringar",
+    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktivera detta för att använda den beräknade nästa uppdateringstiden för flödesuppdateringar. Inaktivera för att uppdatera flöden baserat enbart på uppdateringsintervallet.",
     "Article list" : "Artikellista",
     "Article details" : "Artikeldetaljer",
     "No article selected" : "Ingen artikel har valts",
     "Please select an article from the list..." : "Välj en artikel från listan...",
-    "Move feed to folder" : "Flytta flödet till mappen",
     "Move" : "Flytta",
     "User Name" : "Användarnamn",
     "Share" : "Dela",
@@ -62,13 +66,20 @@ OC.L10N.register(
     "Explore" : "Utforska",
     "Settings" : "Inställningar",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "Article feed information" : "Artikelflödesinformation",
+    "Display mode" : "Visningsläge",
+    "Split mode" : "Delat läge",
     "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
-    "Compact view" : "Kompakt vy",
-    "Expanded compact view" : "Utökad kompakt vy",
     "Show all articles" : "Visa alla artiklar",
     "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
     "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
     "Abonnements (OPML)" : "Prenumerationer (OPML)",
+    "Default" : "Förvald",
+    "Compact" : "Kompakt",
+    "Screenreader" : "Skärmläsare",
+    "Vertical" : "Vertikal",
+    "Horizontal" : "Horisontell",
+    "Off" : "Av",
     "Please select a valid OPML file" : "Välj en giltig OPML-fil",
     "File successfully uploaded" : "Filen har laddats upp",
     "Error uploading the opml file" : "Fel vid uppladdning av opml-filen",
@@ -100,7 +111,6 @@ OC.L10N.register(
     "Download audio" : "Hämta ljud",
     "Download video" : "Hämta video",
     "Open website" : "Öppna webbplats",
-    "Open article" : "Öppna artikel",
     "Keep article unread" : "Behåll artikel oläst",
     "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
     "Remove keep article unread" : "Ta bort behåll artikel oläst",
@@ -110,12 +120,24 @@ OC.L10N.register(
     "{num} days ago" : "{num} dagar sedan",
     "{num} months ago" : "{num} månader sedan",
     "{num} years ago" : "{num} år sedan",
+    "Last update" : "Senaste uppdatering",
+    "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
+    "Next update" : "Nästa uppdatering",
+    "Time when the next feed update will be done" : "Tidpunkt då nästa flödesuppdatering kommer att göras",
+    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Endast om det är aktiverat i admininställningarna, annars används det vanliga uppdateringsintervallet",
+    "Articles per update" : "Artiklar per uppdatering",
+    "Maximum number of articles reached in a feed update" : "Maximalt antal artiklar nådda i en flödesuppdatering",
+    "Error Count" : "Antal fel",
+    "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
+    "Title" : "Titel",
+    "Not available" : "Inte tillgänglig",
     "Keyboard shortcut" : "Tangentbordsgenvägar",
     "Action" : "Ågärd",
-    "right" : "Höger",
     "Jump to next article" : "Hoppa till nästa artikel",
-    "left" : "vänster",
+    "(screenreader mode)" : "(skärmläsarläge)",
     "Jump to previous article" : "Hoppa till föregående artikel",
+    "right" : "Höger",
+    "left" : "vänster",
     "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
     "Open article in new tab" : "Öppna artikeln i ny flik",
     "Show article details in compact view" : "Visa artikeldetaljer i kompakt vy",
@@ -162,6 +184,7 @@ OC.L10N.register(
     "Collapse" : "Dölj",
     "Deleted folder" : "Raderad mapp",
     "Undo delete folder" : "Ångra radera mapp",
+    "Compact view" : "Kompakt vy",
     "Expand articles on key navigation" : "Expandera artiklar vid hantering",
     "Subscriptions (OPML)" : "Abonnemang (OPML)",
     "Import" : "Importera",
